"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SquircleView = SquircleView;
Object.defineProperty(exports, "getSvgPath", {
  enumerable: true,
  get: function () {
    return _figmaSquircle.getSvgPath;
  }
});

var React = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeSvg = _interopRequireWildcard(require("react-native-svg"));

var _figmaSquircle = require("figma-squircle");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function SquircleView({
  squircleParams,
  children,
  ...rest
}) {
  return /*#__PURE__*/React.createElement(_reactNative.View, rest, /*#__PURE__*/React.createElement(SquircleBackground, squircleParams), children);
}

function SquircleBackground({
  cornerRadius = 0,
  topLeftCornerRadius,
  topRightCornerRadius,
  bottomRightCornerRadius,
  bottomLeftCornerRadius,
  cornerSmoothing,
  fillColor = '#000',
  strokeColor = '#000',
  strokeWidth = 0
}) {
  return /*#__PURE__*/React.createElement(Rect, {
    style: _reactNative.StyleSheet.absoluteFill
  }, ({
    width,
    height
  }) => {
    const hasStroke = strokeWidth > 0;

    if (!hasStroke) {
      const squirclePath = (0, _figmaSquircle.getSvgPath)({
        width,
        height,
        cornerSmoothing,
        cornerRadius,
        topLeftCornerRadius,
        topRightCornerRadius,
        bottomRightCornerRadius,
        bottomLeftCornerRadius
      });
      return /*#__PURE__*/React.createElement(_reactNativeSvg.default, {
        width: "100%",
        height: "100%",
        viewBox: `0 0 ${width} ${height}`
      }, /*#__PURE__*/React.createElement(_reactNativeSvg.Path, {
        d: squirclePath,
        fill: fillColor
      }));
    } else {
      const cornerRadii = [cornerRadius, topLeftCornerRadius, topRightCornerRadius, bottomLeftCornerRadius, bottomRightCornerRadius].filter(cornerRadius => typeof cornerRadius === 'number');
      const maxStrokeWidth = Math.min(...cornerRadii);
      strokeWidth = Math.min(strokeWidth, maxStrokeWidth);
      const insetAmount = strokeWidth / 2;
      const insetSquirclePath = (0, _figmaSquircle.getSvgPath)({
        width: width - strokeWidth,
        height: height - strokeWidth,
        cornerSmoothing,
        cornerRadius: getInnerRadius(cornerRadius, insetAmount),
        topLeftCornerRadius: getInnerRadius(topLeftCornerRadius, insetAmount),
        topRightCornerRadius: getInnerRadius(topRightCornerRadius, insetAmount),
        bottomRightCornerRadius: getInnerRadius(bottomRightCornerRadius, insetAmount),
        bottomLeftCornerRadius: getInnerRadius(bottomLeftCornerRadius, insetAmount)
      });
      return /*#__PURE__*/React.createElement(_reactNativeSvg.default, {
        width: "100%",
        height: "100%",
        viewBox: `0 0 ${width} ${height}`
      }, /*#__PURE__*/React.createElement(_reactNativeSvg.Path, {
        d: insetSquirclePath,
        fill: fillColor,
        stroke: strokeColor,
        strokeWidth: strokeWidth,
        translate: insetAmount
      }));
    }
  });
}

function getInnerRadius(radius, insetAmount) {
  if (radius) {
    return Math.max(0, radius - insetAmount);
  }

  return radius;
} // Inspired by https://reach.tech/rect/


function Rect({
  children,
  ...rest
}) {
  const [rect, setRect] = (0, React.useState)(null);
  return /*#__PURE__*/React.createElement(_reactNative.View, _extends({}, rest, {
    onLayout: e => {
      setRect({
        width: e.nativeEvent.layout.width,
        height: e.nativeEvent.layout.height
      });
    }
  }), rect ? children(rect) : null);
}
//# sourceMappingURL=index.js.map