function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import * as React from 'react';
import { View, StyleSheet } from 'react-native';
import { useState } from 'react';
import Svg, { Path } from 'react-native-svg';
import { getSvgPath } from 'figma-squircle';

function SquircleView({
  squircleParams,
  children,
  ...rest
}) {
  return /*#__PURE__*/React.createElement(View, rest, /*#__PURE__*/React.createElement(SquircleBackground, squircleParams), children);
}

function SquircleBackground({
  cornerRadius = 0,
  topLeftCornerRadius,
  topRightCornerRadius,
  bottomRightCornerRadius,
  bottomLeftCornerRadius,
  cornerSmoothing,
  fillColor = '#000',
  strokeColor = '#000',
  strokeWidth = 0
}) {
  return /*#__PURE__*/React.createElement(Rect, {
    style: StyleSheet.absoluteFill
  }, ({
    width,
    height
  }) => {
    const hasStroke = strokeWidth > 0;

    if (!hasStroke) {
      const squirclePath = getSvgPath({
        width,
        height,
        cornerSmoothing,
        cornerRadius,
        topLeftCornerRadius,
        topRightCornerRadius,
        bottomRightCornerRadius,
        bottomLeftCornerRadius
      });
      return /*#__PURE__*/React.createElement(Svg, {
        width: "100%",
        height: "100%",
        viewBox: `0 0 ${width} ${height}`
      }, /*#__PURE__*/React.createElement(Path, {
        d: squirclePath,
        fill: fillColor
      }));
    } else {
      const cornerRadii = [cornerRadius, topLeftCornerRadius, topRightCornerRadius, bottomLeftCornerRadius, bottomRightCornerRadius].filter(cornerRadius => typeof cornerRadius === 'number');
      const maxStrokeWidth = Math.min(...cornerRadii);
      strokeWidth = Math.min(strokeWidth, maxStrokeWidth);
      const insetAmount = strokeWidth / 2;
      const insetSquirclePath = getSvgPath({
        width: width - strokeWidth,
        height: height - strokeWidth,
        cornerSmoothing,
        cornerRadius: getInnerRadius(cornerRadius, insetAmount),
        topLeftCornerRadius: getInnerRadius(topLeftCornerRadius, insetAmount),
        topRightCornerRadius: getInnerRadius(topRightCornerRadius, insetAmount),
        bottomRightCornerRadius: getInnerRadius(bottomRightCornerRadius, insetAmount),
        bottomLeftCornerRadius: getInnerRadius(bottomLeftCornerRadius, insetAmount)
      });
      return /*#__PURE__*/React.createElement(Svg, {
        width: "100%",
        height: "100%",
        viewBox: `0 0 ${width} ${height}`
      }, /*#__PURE__*/React.createElement(Path, {
        d: insetSquirclePath,
        fill: fillColor,
        stroke: strokeColor,
        strokeWidth: strokeWidth,
        translate: insetAmount
      }));
    }
  });
}

function getInnerRadius(radius, insetAmount) {
  if (radius) {
    return Math.max(0, radius - insetAmount);
  }

  return radius;
} // Inspired by https://reach.tech/rect/


function Rect({
  children,
  ...rest
}) {
  const [rect, setRect] = useState(null);
  return /*#__PURE__*/React.createElement(View, _extends({}, rest, {
    onLayout: e => {
      setRect({
        width: e.nativeEvent.layout.width,
        height: e.nativeEvent.layout.height
      });
    }
  }), rect ? children(rect) : null);
}

export { SquircleView, getSvgPath };
//# sourceMappingURL=index.js.map